@@ -29,16 +29,9 @@
 #include <tqmap.h>
 #include <tqvaluevector.h>
 #include <tqtextcodec.h> 
-
 #include "libchmtextencoding.h"
 
-// TQt3/TQt4 compatibility: in TQt3 TQVector stores pointers, not values - so TQValueVector should be used. 
-// In TQt4 TQVector stores values, so we can use TQVector
-#if defined (USE_TQT_4)
-	#define	QT34VECTOR	TQVector
-#else
-	#define	QT34VECTOR	TQValueVector
-#endif
+#define	QT34VECTOR	TQValueVector
 
 
 //! Contains different (non-standard) image types
